@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -35,6 +35,7 @@ Estimation Applications
    :toctree: ../stubs/
    :nosignatures:
 
+   EstimationApplication
    EuropeanCallDelta
    EuropeanCallPricing
    FixedIncomePricing
@@ -42,12 +43,18 @@ Estimation Applications
 
 """
 
-from .estimation import EuropeanCallDelta, EuropeanCallPricing, FixedIncomePricing
+from .estimation import (
+    EstimationApplication,
+    EuropeanCallDelta,
+    EuropeanCallPricing,
+    FixedIncomePricing,
+)
 from .optimization import PortfolioOptimization, PortfolioDiversification
 
 __all__ = [
     "PortfolioOptimization",
     "PortfolioDiversification",
+    "EstimationApplication",
     "EuropeanCallDelta",
     "EuropeanCallPricing",
     "FixedIncomePricing",
