@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2019, 2021.
+# (C) Copyright IBM 2019, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -11,4 +11,14 @@
 # that they have been altered from the originals.
 
 
-"""Quantum circuit for Finance."""
+"""
+Circuit library (:mod:`qiskit_finance.circuit`)
+===============================================
+
+.. currentmodule:: qiskit_finance.circuit
+
+.. autosummary::
+   :toctree:
+
+   library
+"""
