@@ -16,10 +16,9 @@ import unittest
 from test import QiskitFinanceTestCase
 
 import numpy as np
-
 from qiskit.circuit.library import IntegerComparator
 from qiskit.quantum_info import Operator
-from qiskit.utils import QuantumInstance
+from qiskit.utils import QuantumInstance, optionals
 from qiskit.algorithms import IterativeAmplitudeEstimation, EstimationProblem
 from qiskit_finance.circuit.library import LogNormalDistribution
 
@@ -47,15 +46,9 @@ class TestEuropeanCallDelta(QiskitFinanceTestCase):
 
         self.assertTrue(Operator(ecd).equiv(comparator))
 
+    @unittest.skipUnless(optionals.HAS_AER, "qiskit-aer is required to run this test")
     def test_application(self):
         """Test an end-to-end application."""
-        try:
-            from qiskit import (
-                Aer,
-            )  # pylint: disable=unused-import,import-outside-toplevel
-        except ImportError as ex:  # pylint: disable=broad-except
-            self.skipTest(f"Aer doesn't appear to be installed. Error: '{str(ex)}'")
-            return
 
         num_qubits = 3
 
@@ -101,8 +94,13 @@ class TestEuropeanCallDelta(QiskitFinanceTestCase):
         )
 
         # run amplitude estimation
+        import importlib
+
+        aer = importlib.import_module("qiskit.providers.aer")
         q_i = QuantumInstance(
-            Aer.get_backend("aer_simulator"), seed_simulator=125, seed_transpiler=80
+            aer.Aer.get_backend("aer_simulator"),
+            seed_simulator=125,
+            seed_transpiler=80,
         )
         iae = IterativeAmplitudeEstimation(epsilon_target=0.01, alpha=0.05, quantum_instance=q_i)
         result = iae.estimate(problem)
