@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2019, 2021.
+# (C) Copyright IBM 2019, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -13,10 +13,12 @@
 """ Test Data Providers """
 
 import unittest
+import warnings
 import os
 import datetime
-from test import QiskitFinanceTestCase, requires_extra_library
+from test import QiskitFinanceTestCase
 from ddt import ddt, data, unpack
+import nasdaqdatalink
 import numpy as np
 from qiskit_finance import QiskitFinanceError
 from qiskit_finance.data_providers import (
@@ -33,12 +35,24 @@ from qiskit_finance.data_providers import (
 class TestDataProviders(QiskitFinanceTestCase):
     """Tests data providers for the Portfolio Optimization and Diversification."""
 
+    logger = None
+
     def setUp(self):
         super().setUp()
-        self._quandl_token = os.getenv("QUANDL_TOKEN") if os.getenv("QUANDL_TOKEN") else ""
-        self._on_demand_token = os.getenv("ON_DEMAND_TOKEN") if os.getenv("ON_DEMAND_TOKEN") else ""
+        self._nasdaq_data_link_api_key = (
+            os.getenv("NASDAQ_DATA_LINK_API_KEY") if os.getenv("NASDAQ_DATA_LINK_API_KEY") else None
+        )
+        self._on_demand_token = (
+            os.getenv("ON_DEMAND_TOKEN") if os.getenv("ON_DEMAND_TOKEN") else None
+        )
+        warnings.filterwarnings(action="ignore", message="unclosed", category=ResourceWarning)
+        warnings.filterwarnings(action="ignore", module="urllib3", category=DeprecationWarning)
+
+    def tearDown(self):
+        super().tearDown()
+        warnings.filterwarnings(action="default", message="unclosed", category=ResourceWarning)
+        warnings.filterwarnings(action="default", module="urllib3", category=DeprecationWarning)
 
-    @requires_extra_library
     def test_random_wrong_use(self):
         """Random wrong use test"""
         rnd = RandomDataProvider(seed=1)
@@ -50,7 +64,7 @@ class TestDataProviders(QiskitFinanceTestCase):
         with self.subTest("test RandomDataProvider get_similarity_matrix"):
             self.assertRaises(QiskitFinanceError, rnd.get_similarity_matrix)
         wiki = WikipediaDataProvider(
-            token=self._quandl_token,
+            token=self._nasdaq_data_link_api_key,
             tickers=["GOOG", "AAPL"],
             start=datetime.datetime(2016, 1, 1),
             end=datetime.datetime(2016, 1, 30),
@@ -61,7 +75,6 @@ class TestDataProviders(QiskitFinanceTestCase):
         with self.subTest("test WikipediaDataProvider get_similarity_matrix"):
             self.assertRaises(QiskitFinanceError, wiki.get_similarity_matrix)
 
-    @requires_extra_library
     def test_yahoo_wrong_use(self):
         """Yahoo! wrong use test"""
         yahoo = YahooDataProvider(
@@ -75,7 +88,6 @@ class TestDataProviders(QiskitFinanceTestCase):
         with self.subTest("test YahooDataProvider get_similarity_matrix"):
             self.assertRaises(QiskitFinanceError, yahoo.get_similarity_matrix)
 
-    @requires_extra_library
     def test_random(self):
         """random test"""
         similarity = np.array([[1.00000000e00, 6.2284804e-04], [6.2284804e-04, 1.00000000e00]])
@@ -87,7 +99,6 @@ class TestDataProviders(QiskitFinanceTestCase):
         with self.subTest("test RandomDataProvider get_similarity_matrix"):
             np.testing.assert_array_almost_equal(rnd.get_similarity_matrix(), similarity, decimal=3)
 
-    @requires_extra_library
     def test_random_divide_0(self):
         """Random divide by 0 test"""
         # This will create data with some 0 values, it should not throw
@@ -109,12 +120,11 @@ class TestDataProviders(QiskitFinanceTestCase):
         with self.subTest("test get_period_return_covariance_matrix is numpy array"):
             self.assertIsInstance(sigma_value, np.ndarray)
 
-    @requires_extra_library
     def test_wikipedia(self):
         """wikipedia test"""
         try:
             wiki = WikipediaDataProvider(
-                token=self._quandl_token,
+                token=self._nasdaq_data_link_api_key,
                 tickers=["GOOG", "AAPL"],
                 start=datetime.datetime(2016, 1, 1),
                 end=datetime.datetime(2016, 1, 30),
@@ -133,19 +143,19 @@ class TestDataProviders(QiskitFinanceTestCase):
                     wiki.get_similarity_matrix(), similarity, decimal=3
                 )
         except QiskitFinanceError as ex:
-            self.skipTest(f"Test of WikipediaDataProvider skipped: {str(ex)}")
-            # The trouble for automating testing is that after 50 tries
-            # from one IP address within a day
-            # Quandl complains about the free usage tier limits:
-            # quandl.errors.quandl_error.LimitExceededError: (Status 429) (Quandl Error QELx01)
-            # You have exceeded the anonymous user limit of 50 calls per day. To make more calls
-            # today, please register for a free Quandl account and then include your API
-            # key with your requests.
-            # This gets "dressed" as QiskitFinanceError.
-            # This also introduces a couple of seconds of a delay.
+            if isinstance(ex.__cause__, nasdaqdatalink.LimitExceededError):
+                self.skipTest(f"Test of WikipediaDataProvider skipped: {str(ex)}")
+            else:
+                self.fail(f"Test of WikipediaDataProvider failed: {str(ex)}")
 
     def test_nasdaq(self):
         """nasdaq test"""
+        if self._on_demand_token is None:
+            self.skipTest(
+                "Skipped NASDAQ On Demand test since token was not provided in "
+                "env. variable ON_DEMAND_TOKEN"
+            )
+            return
         try:
             nasdaq = DataOnDemandProvider(
                 token=self._on_demand_token,
@@ -155,14 +165,19 @@ class TestDataProviders(QiskitFinanceTestCase):
             )
             nasdaq.run()
         except QiskitFinanceError as ex:
-            self.skipTest(f"Test of DataOnDemandProvider skipped {str(ex)}")
+            self.fail(f"Test of DataOnDemandProvider failed: {str(ex)}")
 
-    @requires_extra_library
     def test_exchangedata(self):
         """exchange data test"""
+        if self._nasdaq_data_link_api_key is None:
+            self.skipTest(
+                "Skipped NASDAQ Data Link test since token was not provided in "
+                "env. variable NASDAQ_DATA_LINK_API_KEY"
+            )
+            return
         try:
             lse = ExchangeDataProvider(
-                token=self._quandl_token,
+                token=self._nasdaq_data_link_api_key,
                 tickers=["AEO", "ABBY"],
                 stockmarket=StockMarket.LONDON,
                 start=datetime.datetime(2018, 1, 1),
@@ -182,14 +197,13 @@ class TestDataProviders(QiskitFinanceTestCase):
                     lse.get_similarity_matrix(), similarity, decimal=3
                 )
         except QiskitFinanceError as ex:
-            self.skipTest(f"Test of ExchangeDataProvider skipped {str(ex)}")
+            self.fail(f"Test of ExchangeDataProvider failed: {str(ex)}")
 
     @data(
         [["AEO", "AEP"], [[7.0, 1.0], [1.0, 15.0]], [[1.0e00, 9.2e-05], [9.2e-05, 1.0e00]]],
         ["AEO", 7.0, [[1.0]]],
     )
     @unpack
-    @requires_extra_library
     def test_yahoo(self, tickers, covariance, similarity):
         """Yahoo data test"""
         yahoo = YahooDataProvider(
@@ -208,7 +222,7 @@ class TestDataProviders(QiskitFinanceTestCase):
                     yahoo.get_similarity_matrix(), np.array(similarity), decimal=1
                 )
         except QiskitFinanceError as ex:
-            self.skipTest(f"Test of YahooDataProvider skipped {str(ex)}")
+            self.fail(f"Test of YahooDataProvider failed: {str(ex)}")
 
 
 if __name__ == "__main__":
